==> grpc_1.2.5.orig.tar.gz: grpc-1.2.5/test/cpp/interop/http2_client.h <==
/*
 *
 * Copyright 2016, Google Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef GRPC_TEST_CPP_INTEROP_HTTP2_CLIENT_H
#define GRPC_TEST_CPP_INTEROP_HTTP2_CLIENT_H

#include <memory>

#include <grpc++/channel.h>
#include <grpc/grpc.h>
#include "src/proto/grpc/testing/messages.grpc.pb.h"
#include "src/proto/grpc/testing/test.grpc.pb.h"

namespace grpc {
namespace testing {

class Http2Client {
 public:
  explicit Http2Client(std::shared_ptr<Channel> channel);
  ~Http2Client() {}

  bool DoRstAfterHeader();
  bool DoRstAfterData();
  bool DoRstDuringData();
  bool DoGoaway();
  bool DoPing();
  bool DoMaxStreams();

 private:
  class ServiceStub {
   public:
    ServiceStub(std::shared_ptr<Channel> channel);

    TestService::Stub* Get();

   private:
    std::unique_ptr<TestService::Stub> stub_;
    std::shared_ptr<Channel> channel_;
  };

  void MaxStreamsWorker(std::shared_ptr<grpc::Channel> channel);
  bool AssertStatusCode(const Status& s, StatusCode expected_code);
  Status SendUnaryCall(SimpleResponse* response);
  SimpleRequest BuildDefaultRequest();
  ServiceStub serviceStub_;
  std::shared_ptr<Channel> channel_;
  SimpleRequest defaultRequest_;
};

}  // namespace testing
}  // namespace grpc

#endif  // GRPC_TEST_CPP_INTEROP_HTTP2_CLIENT_H

==> grpc-1.12.1.tar.gz: grpc-1.12.1/test/cpp/interop/http2_client.h <==
/*
 *
 * Copyright 2016 gRPC authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef GRPC_TEST_CPP_INTEROP_HTTP2_CLIENT_H
#define GRPC_TEST_CPP_INTEROP_HTTP2_CLIENT_H

#include <memory>

#include <grpc/grpc.h>
#include <grpcpp/channel.h>
#include "src/proto/grpc/testing/messages.pb.h"
#include "src/proto/grpc/testing/test.grpc.pb.h"

namespace grpc {
namespace testing {

class Http2Client {
 public:
  explicit Http2Client(std::shared_ptr<Channel> channel);
  ~Http2Client() {}

  bool DoRstAfterHeader();
  bool DoRstAfterData();
  bool DoRstDuringData();
  bool DoGoaway();
  bool DoPing();
  bool DoMaxStreams();

 private:
  class ServiceStub {
   public:
    ServiceStub(std::shared_ptr<Channel> channel);

    TestService::Stub* Get();

   private:
    std::unique_ptr<TestService::Stub> stub_;
    std::shared_ptr<Channel> channel_;
  };

  void MaxStreamsWorker(std::shared_ptr<grpc::Channel> channel);
  bool AssertStatusCode(const Status& s, StatusCode expected_code);
  Status SendUnaryCall(SimpleResponse* response);
  SimpleRequest BuildDefaultRequest();
  ServiceStub serviceStub_;
  std::shared_ptr<Channel> channel_;
  SimpleRequest defaultRequest_;
};

}  // namespace testing
}  // namespace grpc

#endif  // GRPC_TEST_CPP_INTEROP_HTTP2_CLIENT_H
